from setuptools import setup

setup(
   name='Rocket_FB_1',
   version='1.0.0',
   author='Fadi',
   author_email='benzaimafadi@gmail.com',
   packages=['Rocket'],
   url='http://pypi.python.org/pypi/Rocket_FB_1/',
   license='LICENSE.txt',
   description='An awesome package that does something',
   long_description=open('README.md').read(),
   long_description_content_type="text/markdown",
   install_requires=['']
)